@@ -89,6 +89,13 @@ class ManageConfigMeta(type):
             else:
                 cls.template_path = '/'.join(parts[3:])
 
+        # Asset analyzers and variations
+        if cls.asset_analyzers is None:
+            cls.asset_analyzers = {}
+
+        if cls.asset_variations is None:
+            cls.asset_variations = {}
+
 
 class ManageConfig(metaclass=ManageConfigMeta):
     """
@@ -119,19 +126,23 @@ class ManageConfig(metaclass=ManageConfigMeta):
     # Templates
     template_path = None
 
+    # Asset analyzers and variations
+    asset_analyzers = None
+    asset_variations = None
+
     @classmethod
-    def add_view_rule(cls, rule, view_type, chainMgr, initial_state=None):
+    def add_view_rule(cls, rule, view_type, chain_mgr, initial_state=None):
         """Add a rule for the given view type"""
         initial_state = initial_state or {}
         cls.blueprint.add_url_rule(
             rule,
             endpoint=cls.endpoint_prefix + view_type,
-            view_func=chainMgr.flask_view(
+            view_func=chain_mgr.flask_view(
                 manage_config=cls,
                 view_type=view_type,
                 **initial_state
                 ),
-            methods=[m.upper() for m in chainMgr.chains.keys()]
+            methods=[m.upper() for m in chain_mgr.chains.keys()]
             )
 
     @classmethod
