@@ -8,7 +8,7 @@ Generic add document chain.
 """
 
 import flask
-from manhattan.assets.fields import AssetField
+from manhattan.assets.fields import AssetField, ImageSetField
 from manhattan.chains import Chain, ChainMgr
 from manhattan.nav import Nav, NavItem
 
@@ -106,7 +106,8 @@ def init_document(state):
     # Populate the document from the form
     for k, v in state.form_data.items():
 
-        if k in state.form and isinstance(state.form[k], AssetField):
+        if k in state.form \
+                and isinstance(state.form[k], (AssetField, ImageSetField)):
             continue
 
         setattr(document, k, v)
